"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StateMachineExecutor = void 0;
const StateTypeExecutorFactory_1 = require("./stateTasks/StateTypeExecutorFactory");
const Logger_1 = require("./utils/Logger");
class StateMachineExecutor {
    constructor(stateMachine) {
        this.stateMachine = stateMachine;
        this.currentStateName = stateMachine.definition.StartAt;
        this.logger = Logger_1.Logger.getInstance();
        this._startDate = new Date();
        this._executionArn = `${this.stateMachine.name}-${this.stateMachine.definition.StartAt}-${this._startDate}`;
    }
    async execute(stateDefinition, inputJson) {
        this.logger.log(`* * * * * ${this.currentStateName} * * * * *`);
        this.logger.log(`input: \n${inputJson ? JSON.stringify(JSON.parse(inputJson), null, 2) : 'undefined'}\n`);
        const typeExecutor = StateTypeExecutorFactory_1.StateTypeExecutorFactory.getExecutor(stateDefinition.Type);
        let stateExecutorOutput;
        try {
            stateExecutorOutput = await typeExecutor.execute(this.stateMachine.name, this.currentStateName, stateDefinition, inputJson);
            if (stateExecutorOutput.End) {
                this.logger.log(`[${this.currentStateName}] State Machine Ended`);
                return stateExecutorOutput.json;
            }
            if (!stateExecutorOutput.Next) {
                this.logger.error('[${this.currentStateName}] Should Have ended');
                throw new Error('Should have ended');
            }
            this.currentStateName = stateExecutorOutput.Next;
            this.logger.log(`Output: \n${JSON.stringify(JSON.parse(stateExecutorOutput.json), null, 2)}\n`);
            this.execute(this.stateMachine.definition.States[stateExecutorOutput.Next], stateExecutorOutput.json);
        }
        catch (error) {
            this.logger.error(error.stack);
        }
    }
    get startDate() {
        return this._startDate;
    }
    get executionArn() {
        return this._executionArn;
    }
}
exports.StateMachineExecutor = StateMachineExecutor;
